@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.15   2015/08/06
+ * Version: 0.1.16   2016/06/07
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -206,6 +206,14 @@ static inline void __list_del_entry(struct list_head *entry)
 
 #endif
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 0, 0)
+#define d_backing_inode(upper) (upper)->d_inode
+#endif
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 14, 0)
+#define d_is_dir(dentry) ({ struct inode *inode = d_backing_inode(dentry); \
+			inode && S_ISDIR(inode->i_mode); })
+#endif
+
 /* Clear CaitSith config. */
 #undef CONFIG_CAITSITH
 #undef CONFIG_CAITSITH_LKM
