@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.15   2015/08/06
+ * Version: 0.1.16   2016/06/07
  */
 
 #include "internal.h"
@@ -335,7 +335,7 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 	if (!MAJOR(sb->s_dev))
 		goto prepend_filesystem_name;
 	{
-		struct inode *inode = sb->s_root->d_inode;
+		struct inode *inode = d_backing_inode(sb->s_root);
 		/*
 		 * Use filesystem name if filesystems does not support rename()
 		 * operation.
@@ -391,7 +391,7 @@ out:
 static char *cs_get_socket_name(const struct path *path, char * const buffer,
 				const int buflen)
 {
-	struct inode *inode = path->dentry->d_inode;
+	struct inode *inode = d_backing_inode(path->dentry);
 	struct socket *sock = inode ? SOCKET_I(inode) : NULL;
 	struct sock *sk = sock ? sock->sk : NULL;
 	if (sk) {
@@ -444,7 +444,7 @@ char *cs_realpath(const struct path *path)
 			pos = dentry->d_op->d_dname(dentry, buf, buf_len - 1);
 			goto encode;
 		}
-		inode = sb->s_root->d_inode;
+		inode = d_backing_inode(sb->s_root);
 		/*
 		 * Use local name for "filesystems without rename() operation"
 		 * or "path without vfsmount" or "absolute name is unavailable"
@@ -459,17 +459,16 @@ char *cs_realpath(const struct path *path)
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
 			cs_realpath_unlock();
 		}
-		if (pos == ERR_PTR(-EINVAL))
-			pos = cs_get_local_path(path->dentry, buf,
-						buf_len - 1);
 #else
 		if (!path->mnt ||
 		    (!inode->i_op->rename && !inode->i_op->rename2))
-			pos = cs_get_local_path(path->dentry, buf,
-						buf_len - 1);
+			pos = ERR_PTR(-EINVAL);
 		else
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
 #endif
+		if (pos == ERR_PTR(-EINVAL))
+			pos = cs_get_local_path(path->dentry, buf,
+						buf_len - 1);
 encode:
 		if (IS_ERR(pos))
 			continue;
