@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.15   2015/08/06
+ * Version: 0.1.16   2016/06/07
  */
 
 #include "caitsith.h"
@@ -1126,13 +1126,8 @@ int cs_open_permission(const struct path *path, const int flag)
 		return 0;
 #endif
 #ifndef CONFIG_CAITSITH_READDIR
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 1, 0)
 	if (d_is_dir(path->dentry))
 		return 0;
-#else
-	if (path->dentry->d_inode && S_ISDIR(path->dentry->d_inode->i_mode))
-		return 0;
-#endif
 #endif
 	r.obj.path[0] = *path;
 	if (!(cs_flags & CS_TASK_IS_IN_EXECVE))
@@ -2352,7 +2347,7 @@ void cs_get_attributes(struct cs_request_info *r)
 			dentry = dget_parent(dentry);
 			break;
 		}
-		inode = dentry->d_inode;
+		inode = d_backing_inode(dentry);
 		if (inode) {
 			struct cs_mini_stat *stat = &r->obj.stat[i];
 			stat->uid  = inode->i_uid;
